==> haskell-statevar-1.1.1.0-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-statevar.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: StateVar
version: 1.1.1.0
id: StateVar-1.1.1.0-BmCYP2gLue736T5hzlFgTZ
key: StateVar-1.1.1.0-BmCYP2gLue736T5hzlFgTZ
license: BSD-3-Clause
copyright: Copyright (C) 2014-2015 Edward A. Kmett, 2009-2018 Sven Panne
maintainer: Sven Panne <svenpanne@gmail.com>
author: Sven Panne and Edward Kmett
homepage: https://github.com/haskell-opengl/StateVar
synopsis: State variables
description:
    This package contains state variables, which are references in the IO monad,
    like IORefs or parts of the OpenGL state.
category: Data
abi: 14f2184827d9ccd91edef0e6749877d7
exposed: True
exposed-modules:
    Data.StateVar
import-dirs: /usr/lib/ghc-8.4.3/site-local/StateVar-1.1.1.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/StateVar-1.1.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/StateVar-1.1.1.0
hs-libraries: HSStateVar-1.1.1.0-BmCYP2gLue736T5hzlFgTZ
depends:
    base-4.11.1.0 stm-2.4.5.0 transformers-0.5.5.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             stm-2.4.5.0=4e743cb5a370ac3fbade528432951c3f
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
haddock-interfaces: /usr/share/doc/haskell-statevar/html/StateVar.haddock
haddock-html: /usr/share/doc/haskell-statevar/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-statevar-1.1.1.1-1-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-statevar.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: StateVar
version: 1.1.1.1
id: StateVar-1.1.1.1-5zTmcSrVbN7I4w3ZMeZaTb
key: StateVar-1.1.1.1-5zTmcSrVbN7I4w3ZMeZaTb
license: BSD-3-Clause
copyright: Copyright (C) 2014-2015 Edward A. Kmett, 2009-2018 Sven Panne
maintainer: Sven Panne <svenpanne@gmail.com>
author: Sven Panne and Edward Kmett
homepage: https://github.com/haskell-opengl/StateVar
synopsis: State variables
description:
    This package contains state variables, which are references in the IO monad,
    like IORefs or parts of the OpenGL state.
category: Data
abi: b777c54e6eb83c2075ba969a9e5dd06d
exposed: True
exposed-modules:
    Data.StateVar
import-dirs: /usr/lib/ghc-8.4.3/site-local/StateVar-1.1.1.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/StateVar-1.1.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/StateVar-1.1.1.1
hs-libraries: HSStateVar-1.1.1.1-5zTmcSrVbN7I4w3ZMeZaTb
depends:
    base-4.11.1.0 stm-2.4.5.0 transformers-0.5.5.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             stm-2.4.5.0=4e743cb5a370ac3fbade528432951c3f
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
haddock-interfaces: /usr/share/doc/haskell-statevar/html/StateVar.haddock
haddock-html: /usr/share/doc/haskell-statevar/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
